import Foundation
import CoreXLSX

guard let file = XLSXFile( filepath: CommandLine.arguments[1] ) else {
    fatalError( "XLSX file \(CommandLine.arguments[1]) corrupted or does not exist" )
}

var rows: [[String]] = []

do {
    let wsPaths = try file.parseWorksheetPaths()
    let sharedStrings = try file.parseSharedStrings()
    let ws = try file.parseWorksheet( at: wsPaths[0] )
    
    for ( index, wsRow ) in ( ws.data?.rows ?? [] ).enumerated() {
        print("Row \(index+1) has \(wsRow.cells.count) cells")
        
        for c in wsRow.cells {
            guard let value = c.value else {
                print( "" )
                continue
            }
            
            guard let type = c.type else {
                print( "   ", value.trimmingCharacters( in: CharacterSet( charactersIn: " " ) ) )
                continue
            }
            
            if type == .sharedString {
                let shared = sharedStrings.items[ Int( c.value! )! ].text!
                print( "   ", shared.trimmingCharacters( in: CharacterSet( charactersIn: " " ) ) )
            } else {
                fatalError( "Unknow cell type \(type) at \(c.reference)" )
            }
        }
    }
} catch {
    fatalError( "Error parsing XLSX file \(CommandLine.arguments[1] )" )
}
